**************************************************************************
*
* MsgBox (Clipper only version)
*
* By David A. Richardson [72271,53]
* Copyright (C) 1990 David A. Richardson
*
* Also included are crestbox() and csavebox() - the Clipper versions of
* Proclip's savebox() and restbox()
*
* These functions are free.  Modify and use them as you like. 
*
* Date:    January 14, 1990
* Syntax:  msgbox(str, str, str, auto, get, beep)     
* Returns: The saved screen area (string), or a logical based on
*          the users response to a YN prompt, or .t.
*          (See README.MSG)
*
**************************************************************************

function MsgBox
parameters msg1, msg2, msg3, action, beep, boxt

private i, boxl, boxh, boxt, boxoff, ocolor, ok, rval, nargs, ;
        nomsg2, nomsg3, lmsg1, lmsg2, lmsg3, maxl, obox 

set cursor off
*
* Initilaize the defaults
*
          
nargs=  pcount()
ocolor= setcolor( clr_msgbox )
nomsg2= .t.
nomsg3= .t.
ok=     " "
rval=   .t.
boxh=   4
mget=   .f.
pause=  .f.
lmsg1=  len( msg1 )
lmsg2=  0 
lmsg3=  0

*
* Check the parameters
*

if nargs < 6
   boxt= -1
endif

if nargs < 5
   beep= 0
endif

if nargs < 4 
   action= ""
endif

if nargs < 3
   msg3= ""
else 
   lmsg3= len( msg3 )
   if lmsg3 > 0
      nomsg3= .f.
      boxh= boxh + 2
   endif
endif

if nargs < 2 
   msg2= ""
else
   lmsg2= len( msg2 )
   if lmsg2 > 0
      nomsg2= .f.
      boxh= boxh + 2
   endif
endif

*
* The following can be handled in two lines if you're
* willing to use macros
*

if action= "g"

   if !nomsg3
      lmsg3= lmsg3 + 6
   elseif !nomsg2
      lmsg2= lmsg2 + 6
   else
      lmsg1= lmsg1 + 6
   endif

endif

*
* Set the sizes
*

maxl= max( max( lmsg1, lmsg2 ), lmsg3 )
boxl= if( maxl < 8, 15, maxl + 6 )

if action == "p"
   boxh= boxh + 1
   boxl= max( boxl, 32 )
endif

boxt= if( boxt < 0,( 25 - boxh ) /2, boxt )
boxoff= ( 80 - boxl ) /2 

obox= csavebox( boxt, boxoff, boxt + boxh, boxoff + boxl )


*
* Print the box and text to the screen
*
@ boxt, boxoff, boxt + boxh, boxoff + boxl box boxframe

set color to ( clr_msgtxt )
@ boxt + 2, boxoff + ( boxl-lmsg1 ) /2 say msg1

if !nomsg2
   @ boxt + 4, boxoff + ( boxl-lmsg2 ) /2 say msg2
endif

if !nomsg3
   @ boxt + 6, boxoff + ( boxl-lmsg3 ) /2 say msg3
endif

@ boxt + boxh-2, col() say if(action == "g", "(Y,N) ", "")

*
* Do the rest
*
for i= 1 to beep
   tone( 1000, 1 )
next

if action == "g" 

   set cursor on 
   do while !ok $ "YN"

      if !rval
         tone( 250, 1 )
      endif

      ok= upper( chr( inkey( 0 )))

      rval= ( ok == "Y" )

   enddo
   set cursor off
   crestbox( obox )

elseif action == "p"

   set color to ( "*" + clr_msgtxt )
   @ boxt + boxh -1, boxoff + 2 say "Press any key..."
   clear typeahead
   inkey( 0 )
   crestbox( obox )

else 

   rval= obox

endif

set color to ( ocolor )
set cursor on
return rval

*** eof msgBox ***


*
* The following 2 functions, csavebox() and crestbox(), were included
* so that the straight Clipper version of the msgbox() function would  
* work similarly to the Proclip version.  Although these functions do
* what is needed for MsgBox, they are a far cry from Proclip boxes and 
* all the associated functions. 
*

function csavebox
parameters x1,y1,x2,y2
return( str( int( x1 ), 2) + str ( int ( y1 ), 2) + str( int( x2-x1 ), 2) +;
        str( int( y2-y1 ), 2) + savescreen( x1, y1, x2, y2 ))

*** eof csavebox *** 

*
* Note that restbox() can be called with the variable name of the 
* saved area only, or may be passed new X and Y starting coordinates
* This functionality mimics that of Proclip's restbox()
*

function crestbox
parameters x, y, mbox
private x1, y1, x2, y2

if pcount() == 3

   x1= x
   y1= y

else

   mbox= x
   x1= val( left( mbox, 2 ))
   y1= val( substr( mbox, 3, 2 ))

endif

x2= x1 + val( substr( mbox, 5, 2 ))
y2= y1 + val( substr( mbox, 7, 2 ))

restscreen( x1, y1, x2, y2, substr( mbox, 9 ))

return ""

*** eof crestbox ***
